==> openshift-model-operator-4.11.2-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/DNSListFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface DNSListFluent<A extends DNSListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,DNS item);
    public A setToItems(int index,DNS item);
    public A addToItems(DNS... items);
    public A addAllToItems(Collection<DNS> items);
    public A removeFromItems(DNS... items);
    public A removeAllFromItems(Collection<DNS> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<DNSBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<DNS> getItems();
    public List<DNS> buildItems();
    public DNS buildItem(int index);
    public DNS buildFirstItem();
    public DNS buildLastItem();
    public DNS buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<DNSBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<DNSBuilder> predicate);
    public A withItems(List<DNS> items);
    public A withItems(DNS... items);
    public Boolean hasItems();
    public DNSListFluent.ItemsNested<A> addNewItem();
    public DNSListFluent.ItemsNested<A> addNewItemLike(DNS item);
    public DNSListFluent.ItemsNested<A> setNewItemLike(int index,DNS item);
    public DNSListFluent.ItemsNested<A> editItem(int index);
    public DNSListFluent.ItemsNested<A> editFirstItem();
    public DNSListFluent.ItemsNested<A> editLastItem();
    public DNSListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<DNSBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSFluent<DNSListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> openshift-model-operator-5.0.2-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/DNSListFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface DNSListFluent<A extends DNSListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,DNS item);
    public A setToItems(int index,DNS item);
    public A addToItems(DNS... items);
    public A addAllToItems(Collection<DNS> items);
    public A removeFromItems(DNS... items);
    public A removeAllFromItems(Collection<DNS> items);
    public A removeMatchingFromItems(Predicate<DNSBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<DNS> getItems();
    public List<DNS> buildItems();
    public DNS buildItem(int index);
    public DNS buildFirstItem();
    public DNS buildLastItem();
    public DNS buildMatchingItem(Predicate<DNSBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<DNSBuilder> predicate);
    public A withItems(List<DNS> items);
    public A withItems(DNS... items);
    public Boolean hasItems();
    public DNSListFluent.ItemsNested<A> addNewItem();
    public DNSListFluent.ItemsNested<A> addNewItemLike(DNS item);
    public DNSListFluent.ItemsNested<A> setNewItemLike(int index,DNS item);
    public DNSListFluent.ItemsNested<A> editItem(int index);
    public DNSListFluent.ItemsNested<A> editFirstItem();
    public DNSListFluent.ItemsNested<A> editLastItem();
    public DNSListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSFluent<DNSListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
